@@ -4,7 +4,7 @@
   cat("\n--------\n\n")
   cat("\n", citation("sdcMicro")$note, "has been loaded.\n\n" )
   cat("--------\n\n")
-  cat("\n If you want to use the sdcMicro GUI, type \n" )  
+  cat("\n If you want to work with the GUI of sdcMicro GUI, type \n" )  
   cat("\n sdcGUI()\n\n" )  
   cat("--------\n\n")
 }
